<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:cap="http://www.incident.com/cap/bogus" xmlns:jdd="http://www.it.ojp.gov/jxdd/prerelease/3.0.0.0" xmlns:cd="http://www.incident.com/cap/bogus" xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance">

	<xsl:variable name="CodeDoc" select="'CAPCodes.xml'"/>
	<xsl:variable name="capRoot" select="/cap:AlertMessage"/>
	
	<xsl:template match="/cap:AlertMessage">
		<html>
			<head>
				<title>CAP Alert - <xsl:value-of select="jdd:Alert/jdd:AlertEventTypeText"/></title>
			</head>
			<body>
			
				<br/><br/>

				<table border="1" cellpadding="5" width="85%">
					<col width="15%"/><col width="*"/><col width="15%"/>
					<tr>
						<td colspan="3" align="center"><br/><h2>CAP Alert Message</h2></td>
					</tr>
					<tr>
						<td>Sender</td>
						<td><b><xsl:value-of select="SenderID"/></b></td>
						<td rowspan="20" align="right" valign="top">
							<table cellpadding="5">
								<tr>
									<td colspan="2"><u>Message Characteristics</u></td>
								</tr>
								<tr>
									<td>
										<b>
											Status:<br/>
											Scope:<br/>
											Type:<br/>
										</b>
									</td>
									<td>
										<xsl:value-of select="MessageStatusCode"/><br/>
										<xsl:value-of select="MessageScopeCode"/><br/>
										<xsl:value-of select="MessageTypeCode"/><br/>
									</td>
								</tr>
								<tr>
									<td colspan="2"><hr/></td>
								</tr>
								<tr>
									<td colspan="2"><u>Alert Characteristics</u></td>
								</tr>
								<tr>
									<td>
										<b>
											Category:<br/>
											Urgency:<br/>
											Severity:<br/>
											Certainty:<br/>
										</b>
									</td>
									<td>
										<xsl:value-of select="jdd:Alert/jdd:AlertEventCategoryCode"/><br/>
										<xsl:value-of select="jdd:Alert/jdd:AlertUrgencyCode"/><br/>
										<xsl:value-of select="jdd:Alert/jdd:AlertSeverityCode"/><br/>
										<xsl:value-of select="jdd:Alert/jdd:AlertCertaintyCode"/><br/>
									</td>
								</tr>
							</table>
						</td>
					</tr>
					<tr>
						<td>Sent</td>
						<td>
							<xsl:value-of select="substring(SentDateTime, 1, 10)"/>
							<xsl:text>,  </xsl:text>
							<xsl:value-of select="substring(SentDateTime, 12, 14)"/>
						</td>
					</tr>
					<tr>
						<td>Message ID</td>
						<td><xsl:value-of select="MessageID"/></td>
					</tr>
					<tr>
						<td>Alert</td>
						<td>
							<b><xsl:value-of select="jdd:Alert/jdd:AlertEventTypeText"/></b>
							<br/><br/>
							<xsl:value-of select="jdd:Alert/jdd:AlertEventDescriptionText"/>
							<br/>
							<br/>
						</td>
					</tr>
					<tr>
						<td>Information Links</td>
						<td>
							<xsl:call-template name="PrintLinks"><xsl:with-param name="FieldName" select="'jdd:AlertInformationURLID'"/></xsl:call-template>
						</td>
					</tr>
					<tr>
						<td>Image Links</td>
						<td>
							<xsl:call-template name="PrintLinks"><xsl:with-param name="FieldName" select="'jdd:AlertImageURLID'"/></xsl:call-template>
						</td>
					</tr>
					<tr>
						<td>Audio Links</td>
						<td>
							<xsl:call-template name="PrintLinks"><xsl:with-param name="FieldName" select="'jdd:AlertAudioURLID'"/></xsl:call-template>
						</td>
					</tr>
					<tr>
						<td>Parameters</td>
						<td>
							<xsl:for-each select="jdd:Alert/jdd:AlertParameterCodeText">
								<xsl:value-of select="."/><br/>
							</xsl:for-each>
						</td>
					</tr>
				</table>
			</body>
		</html>
	</xsl:template>
	
	
	<xsl:template name="PrintLinks">
		<xsl:param name="FieldName"/>
		
		<!-- Print a hyperlink for each value of the given field -->
		<xsl:for-each select="jdd:Alert/* [name() = $FieldName]">
			<a>
				<xsl:attribute name="href"><xsl:value-of select="."/></xsl:attribute>
				<xsl:value-of select="."/>
			</a>
		</xsl:for-each>
		
		<!-- Print a break line statement if no links exists so a table cell will display correctly -->
		<xsl:if test="count(//* [name() = $FieldName]) = 0">
			<br/>
		</xsl:if>
	</xsl:template>
	
	
</xsl:stylesheet>
